@@ -1,8 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-import unittest
 import doctest
+import os
+import unittest
 
 from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import suite as test_suite
@@ -18,8 +19,9 @@ def suite():
     suite = test_suite()
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             StockPackageShippingDpdTestCase))
-    suite.addTests(doctest.DocFileSuite('scenario_shipping_dpd.rst',
-            tearDown=doctest_teardown, encoding='utf-8',
-            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE,
-            checker=doctest_checker))
+    if os.getenv('DPD_USER_ID') and os.getenv('DPD_PASSWORD'):
+        suite.addTests(doctest.DocFileSuite('scenario_shipping_dpd.rst',
+                tearDown=doctest_teardown, encoding='utf-8',
+                optionflags=doctest.REPORT_ONLY_FIRST_FAILURE,
+                checker=doctest_checker))
     return suite
